pub struct MockPamAccessConnectorsApi {
PamAccessConnectorsApi_expectations: MockPamAccessConnectorsApi_PamAccessConnectorsApi,
}Fields
PamAccessConnectorsApi_expectations: MockPamAccessConnectorsApi_PamAccessConnectorsApiImplementations
Sourceimpl MockPamAccessConnectorsApi
impl MockPamAccessConnectorsApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockPamAccessConnectorsApi
impl MockPamAccessConnectorsApi
Sourcepub fn expect_assign_target(&mut self) -> &mut Expectation
pub fn expect_assign_target(&mut self) -> &mut Expectation
Create an Expectation for mocking the assign_target method
Sourcepub fn expect_delete(&mut self) -> &mut Expectation
pub fn expect_delete(&mut self) -> &mut Expectation
Create an Expectation for mocking the delete method
Sourcepub fn expect_disable(&mut self) -> &mut Expectation
pub fn expect_disable(&mut self) -> &mut Expectation
Create an Expectation for mocking the disable method
Sourcepub fn expect_enable(&mut self) -> &mut Expectation
pub fn expect_enable(&mut self) -> &mut Expectation
Create an Expectation for mocking the enable method
Sourcepub fn expect_get(&mut self) -> &mut Expectation
pub fn expect_get(&mut self) -> &mut Expectation
Create an Expectation for mocking the get method
Sourcepub fn expect_get_all(&mut self) -> &mut Expectation
pub fn expect_get_all(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_all method
Sourcepub fn expect_post(&mut self) -> &mut Expectation
pub fn expect_post(&mut self) -> &mut Expectation
Create an Expectation for mocking the post method
Sourcepub fn expect_unassign_target(&mut self) -> &mut Expectation
pub fn expect_unassign_target(&mut self) -> &mut Expectation
Create an Expectation for mocking the unassign_target method